@@ -1,4 +1,4 @@
-$Parse::NetApp::ASUP::VERSION='1.10';
+$Parse::NetApp::ASUP::VERSION='1.13';
 
 =head1 NAME:
 
@@ -92,19 +92,16 @@ Returns the version of the loaded ASUP file.
 
 sub asup_version {
 	my $raw = defined $_[0]->{asup} ? $_[0]->{asup} : $_[0];
-	my $version;
-	for my $line ( split '\n', $raw ) {
-		next unless $line =~ /^VERSION=NetApp Release ([\w\.\d]+)/;
-		$version = $1;
-		last;
+	
+	if ( $raw =~ /^VERSION=NetApp Release ([\w\.\d]+)/ms ) {
+		return "$1";
 	}
-	return $version if defined $version;	
-	for my $line ( split '\n', $raw ) {
-		next unless $line =~ /^X-Netapp-asup-os-version: NetApp Release ([\w\.\d]+)/;
-		$version = $1;
-		last;
+	
+	if ( $raw =~ /^X-Netapp-asup-os-version: NetApp Release ([\w\.\d]+)/ms ) {
+		return "$1";
 	}
-	return $version ? $version : 'unknown';
+
+	return 'unknown';
 }	
 
 =head3 extract($raw)
@@ -2905,7 +2902,7 @@ sub extract_xheader {
 
 =head1 AUTHORSHIP:
 
-  Parse::NetApp::ASUP v1.10 2013/02/20
+  Parse::NetApp::ASUP v1.13 2013/03/14
 
   (c) 2012-2013, Phillip Pollard <bennie@cpan.org>
   Released under the Perl Artistic License
\ No newline at end of file
